import React, { useState } from "react";
import { Disclosure } from "@headlessui/react";
import { OpenDisclosure, CloseDisclosure } from "@/components/Icons";
import FormCheck from "@/components/CheckBoxComponent/FormCheck";
import axios from "axios";
import { toast, ToastContainer } from "react-toastify";
import "react-toastify/dist/ReactToastify.css";

export const DealTab = () => {
  const [dealPreferences, setDealPreferences] = useState({
    propertyTypes: [],
    regions: [],
    escrowAccount: [],
    escrowAccountFunds: [],
    carTypes: [],
    boatTypes: [],
    jewelryTypes: [],
  });

  const handleCheckboxChange = (category, value) => {
    setDealPreferences((prev) => {
      const newValues = prev[category].includes(value)
        ? prev[category].filter((item) => item !== value)
        : [...prev[category], value];
      return { ...prev, [category]: newValues };
    });
  };

  const handleSave = async () => {
    try {
      const response = await axios.post(
        "${process.env.NEXT_PUBLIC_BASE_URL}/dealPreferences/add",
        dealPreferences
      );
      toast.success("Deal preferences saved successfully!");
    } catch (error) {
      toast.error("Failed to save deal preferences!");
    }
  };

  return (
    <>
      <span className="text-lg text-prussianBlue/40 mb-4 block">
        Deal Preference
      </span>
      <div className="custom-shadow rounded flex flex-col gap-2">
        <Disclosure as="div" className={`disclosure`} defaultOpen={true}>
          {({ open }) => (
            <>
              <Disclosure.Button
                className={`w-full btn-gradient rounded py-3 px-7 gap-4 justify-between items-center flex ${
                  open && "mb-3"
                }`}
              >
                <span className="whitespace-nowrap sm:text-xl font-medium text-white">
                  Properties
                </span>
                <span className="flex-shrink-0">
                  {open ? (
                    <OpenDisclosure className="text-white" />
                  ) : (
                    <CloseDisclosure className="text-white" />
                  )}
                </span>
              </Disclosure.Button>
              <Disclosure.Panel as="div" className="px-8 py-4">
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">
                          Properties Types
                        </span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="Apartments"
                          id="1"
                          onChange={() =>
                            handleCheckboxChange("propertyTypes", "Apartments")
                          }
                        />
                        <FormCheck
                          label="Workers Housing"
                          id="2"
                          onChange={() =>
                            handleCheckboxChange(
                              "propertyTypes",
                              "Workers Housing"
                            )
                          }
                        />
                        <FormCheck
                          label="Villa"
                          id="3"
                          onChange={() =>
                            handleCheckboxChange("propertyTypes", "Villa")
                          }
                        />
                        <FormCheck
                          label="Student Housing"
                          id="4"
                          onChange={() =>
                            handleCheckboxChange(
                              "propertyTypes",
                              "Student Housing"
                            )
                          }
                        />
                        <FormCheck
                          label="Building"
                          id="5"
                          onChange={() =>
                            handleCheckboxChange("propertyTypes", "Building")
                          }
                        />
                        <FormCheck
                          label="Industrial"
                          id="6"
                          onChange={() =>
                            handleCheckboxChange("propertyTypes", "Industrial")
                          }
                        />
                        <FormCheck
                          label="Office"
                          id="7"
                          onChange={() =>
                            handleCheckboxChange("propertyTypes", "Office")
                          }
                        />
                        <FormCheck
                          label="Land"
                          id="8"
                          onChange={() =>
                            handleCheckboxChange("propertyTypes", "Land")
                          }
                        />
                        <FormCheck
                          label="Retail"
                          id="9"
                          onChange={() =>
                            handleCheckboxChange("propertyTypes", "Retail")
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">Region</span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="US"
                          id="10"
                          onChange={() => handleCheckboxChange("regions", "US")}
                        />
                        <FormCheck
                          label="Europe"
                          id="12"
                          onChange={() =>
                            handleCheckboxChange("regions", "Europe")
                          }
                        />
                        <FormCheck
                          label="Canada"
                          id="13"
                          onChange={() =>
                            handleCheckboxChange("regions", "Canada")
                          }
                        />
                        <FormCheck
                          label="Africa"
                          id="14"
                          onChange={() =>
                            handleCheckboxChange("regions", "Africa")
                          }
                        />
                        <FormCheck
                          label="United Arab Emirates"
                          id="15"
                          onChange={() =>
                            handleCheckboxChange(
                              "regions",
                              "United Arab Emirates"
                            )
                          }
                        />
                        <FormCheck
                          label="Asia"
                          id="16"
                          onChange={() =>
                            handleCheckboxChange("regions", "Asia")
                          }
                        />
                        <FormCheck
                          label="America"
                          id="17"
                          onChange={() =>
                            handleCheckboxChange("regions", "America")
                          }
                        />
                        <FormCheck
                          label="Oceana"
                          id="18"
                          onChange={() =>
                            handleCheckboxChange("regions", "Oceana")
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">
                          Escrow Account
                        </span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="US"
                          id="19"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "US")
                          }
                        />
                        <FormCheck
                          label="Europe"
                          id="20"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Europe")
                          }
                        />
                        <FormCheck
                          label="Canada"
                          id="21"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Canada")
                          }
                        />
                        <FormCheck
                          label="Africa"
                          id="22"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Africa")
                          }
                        />
                        <FormCheck
                          label="United Arab Emirates"
                          id="23"
                          onChange={() =>
                            handleCheckboxChange(
                              "escrowAccount",
                              "United Arab Emirates"
                            )
                          }
                        />
                        <FormCheck
                          label="Asia"
                          id="24"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Asia")
                          }
                        />
                        <FormCheck
                          label="America"
                          id="25"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "America")
                          }
                        />
                        <FormCheck
                          label="Oceana"
                          id="26"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Oceana")
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">
                          Escrow Account Funds
                        </span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="US"
                          id="27"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "US")
                          }
                        />
                        <FormCheck
                          label="Europe"
                          id="28"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Europe")
                          }
                        />
                        <FormCheck
                          label="Canada"
                          id="29"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Canada")
                          }
                        />
                        <FormCheck
                          label="Africa"
                          id="30"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Africa")
                          }
                        />
                        <FormCheck
                          label="United Arab Emirates"
                          id="31"
                          onChange={() =>
                            handleCheckboxChange(
                              "escrowAccountFunds",
                              "United Arab Emirates"
                            )
                          }
                        />
                        <FormCheck
                          label="Asia"
                          id="32"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Asia")
                          }
                        />
                        <FormCheck
                          label="America"
                          id="33"
                          onChange={() =>
                            handleCheckboxChange(
                              "escrowAccountFunds",
                              "America"
                            )
                          }
                        />
                        <FormCheck
                          label="Oceana"
                          id="34"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Oceana")
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
              </Disclosure.Panel>
            </>
          )}
        </Disclosure>
        <Disclosure as="div" className={`disclosure`}>
          {({ open }) => (
            <>
              <Disclosure.Button
                className={`w-full btn-gradient rounded py-3 px-7 gap-4 justify-between items-center flex ${
                  open && "mb-3"
                }`}
              >
                <span className="whitespace-nowrap sm:text-xl font-medium text-white">
                  Cars
                </span>
                <span className="flex-shrink-0">
                  {open ? (
                    <OpenDisclosure className="text-white" />
                  ) : (
                    <CloseDisclosure className="text-white" />
                  )}
                </span>
              </Disclosure.Button>
              <Disclosure.Panel as="div" className="px-8 py-4">
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">Cars Types</span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="Toyota"
                          id="35"
                          onChange={() =>
                            handleCheckboxChange("carTypes", "Toyota")
                          }
                        />
                        <FormCheck
                          label="Mercedes-Benz"
                          id="36"
                          onChange={() =>
                            handleCheckboxChange("carTypes", "Mercedes-Benz")
                          }
                        />
                        <FormCheck
                          label="Fortuner"
                          id="37"
                          onChange={() =>
                            handleCheckboxChange("carTypes", "Fortuner")
                          }
                        />
                        <FormCheck
                          label="BMW"
                          id="38"
                          onChange={() =>
                            handleCheckboxChange("carTypes", "BMW")
                          }
                        />
                        <FormCheck
                          label="Prado"
                          id="39"
                          onChange={() =>
                            handleCheckboxChange("carTypes", "Prado")
                          }
                        />
                        <FormCheck
                          label="Land-Rover"
                          id="40"
                          onChange={() =>
                            handleCheckboxChange("carTypes", "Land-Rover")
                          }
                        />
                        <FormCheck
                          label="4Runner"
                          id="41"
                          onChange={() =>
                            handleCheckboxChange("carTypes", "4Runner")
                          }
                        />
                        <FormCheck
                          label="Lexus"
                          id="42"
                          onChange={() =>
                            handleCheckboxChange("carTypes", "Lexus")
                          }
                        />
                        <FormCheck
                          label="Honda"
                          id="43"
                          onChange={() =>
                            handleCheckboxChange("carTypes", "Honda")
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">Region</span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="US"
                          id="44"
                          onChange={() => handleCheckboxChange("regions", "US")}
                        />
                        <FormCheck
                          label="Europe"
                          id="45"
                          onChange={() =>
                            handleCheckboxChange("regions", "Europe")
                          }
                        />
                        <FormCheck
                          label="Canada"
                          id="46"
                          onChange={() =>
                            handleCheckboxChange("regions", "Canada")
                          }
                        />
                        <FormCheck
                          label="Africa"
                          id="47"
                          onChange={() =>
                            handleCheckboxChange("regions", "Africa")
                          }
                        />
                        <FormCheck
                          label="United Arab Emirates"
                          id="48"
                          onChange={() =>
                            handleCheckboxChange(
                              "regions",
                              "United Arab Emirates"
                            )
                          }
                        />
                        <FormCheck
                          label="Asia"
                          id="49"
                          onChange={() =>
                            handleCheckboxChange("regions", "Asia")
                          }
                        />
                        <FormCheck
                          label="America"
                          id="50"
                          onChange={() =>
                            handleCheckboxChange("regions", "America")
                          }
                        />
                        <FormCheck
                          label="Oceana"
                          id="51"
                          onChange={() =>
                            handleCheckboxChange("regions", "Oceana")
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">
                          Escrow Account
                        </span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="US"
                          id="52"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "US")
                          }
                        />
                        <FormCheck
                          label="Europe"
                          id="53"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Europe")
                          }
                        />
                        <FormCheck
                          label="Canada"
                          id="54"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Canada")
                          }
                        />
                        <FormCheck
                          label="Africa"
                          id="55"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Africa")
                          }
                        />
                        <FormCheck
                          label="United Arab Emirates"
                          id="56"
                          onChange={() =>
                            handleCheckboxChange(
                              "escrowAccount",
                              "United Arab Emirates"
                            )
                          }
                        />
                        <FormCheck
                          label="Asia"
                          id="57"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Asia")
                          }
                        />
                        <FormCheck
                          label="America"
                          id="58"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "America")
                          }
                        />
                        <FormCheck
                          label="Oceana"
                          id="59"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Oceana")
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">
                          Escrow Account Funds
                        </span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="US"
                          id="60"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "US")
                          }
                        />
                        <FormCheck
                          label="Europe"
                          id="61"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Europe")
                          }
                        />
                        <FormCheck
                          label="Canada"
                          id="62"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Canada")
                          }
                        />
                        <FormCheck
                          label="Africa"
                          id="63"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Africa")
                          }
                        />
                        <FormCheck
                          label="United Arab Emirates"
                          id="64"
                          onChange={() =>
                            handleCheckboxChange(
                              "escrowAccountFunds",
                              "United Arab Emirates"
                            )
                          }
                        />
                        <FormCheck
                          label="Asia"
                          id="65"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Asia")
                          }
                        />
                        <FormCheck
                          label="America"
                          id="66"
                          onChange={() =>
                            handleCheckboxChange(
                              "escrowAccountFunds",
                              "America"
                            )
                          }
                        />
                        <FormCheck
                          label="Oceana"
                          id="67"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Oceana")
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
              </Disclosure.Panel>
            </>
          )}
        </Disclosure>
        <Disclosure as="div" className={`disclosure`}>
          {({ open }) => (
            <>
              <Disclosure.Button
                className={`w-full btn-gradient rounded py-3 px-7 gap-4 justify-between items-center flex ${
                  open && "mb-3"
                }`}
              >
                <span className="whitespace-nowrap sm:text-xl font-medium text-white">
                  Boats
                </span>
                <span className="flex-shrink-0">
                  {open ? (
                    <OpenDisclosure className="text-white" />
                  ) : (
                    <CloseDisclosure className="text-white" />
                  )}
                </span>
              </Disclosure.Button>
              <Disclosure.Panel as="div" className="px-8 py-4">
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">Boats Types</span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="Power Boats"
                          id="68"
                          onChange={() =>
                            handleCheckboxChange("boatTypes", "Power Boats")
                          }
                        />
                        <FormCheck
                          label="Motor Boat"
                          id="69"
                          onChange={() =>
                            handleCheckboxChange("boatTypes", "Motor Boat")
                          }
                        />
                        <FormCheck
                          label="Speed Boats"
                          id="70"
                          onChange={() =>
                            handleCheckboxChange("boatTypes", "Speed Boats")
                          }
                        />
                        <FormCheck
                          label="Sail Boats"
                          id="71"
                          onChange={() =>
                            handleCheckboxChange("boatTypes", "Sail Boats")
                          }
                        />
                        <FormCheck
                          label="Prado"
                          id="72"
                          onChange={() =>
                            handleCheckboxChange("boatTypes", "Prado")
                          }
                        />
                        <FormCheck
                          label="Paddle Boats"
                          id="73"
                          onChange={() =>
                            handleCheckboxChange("boatTypes", "Paddle Boats")
                          }
                        />
                        <FormCheck
                          label="Jet Boats"
                          id="74"
                          onChange={() =>
                            handleCheckboxChange("boatTypes", "Jet Boats")
                          }
                        />
                        <FormCheck
                          label="Deck Boats"
                          id="75"
                          onChange={() =>
                            handleCheckboxChange("boatTypes", "Deck Boats")
                          }
                        />
                        <FormCheck
                          label="Cruise Boats"
                          id="76"
                          onChange={() =>
                            handleCheckboxChange("boatTypes", "Cruise Boats")
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">Region</span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="US"
                          id="77"
                          onChange={() => handleCheckboxChange("regions", "US")}
                        />
                        <FormCheck
                          label="Europe"
                          id="78"
                          onChange={() =>
                            handleCheckboxChange("regions", "Europe")
                          }
                        />
                        <FormCheck
                          label="Canada"
                          id="79"
                          onChange={() =>
                            handleCheckboxChange("regions", "Canada")
                          }
                        />
                        <FormCheck
                          label="Africa"
                          id="80"
                          onChange={() =>
                            handleCheckboxChange("regions", "Africa")
                          }
                        />
                        <FormCheck
                          label="United Arab Emirates"
                          id="81"
                          onChange={() =>
                            handleCheckboxChange(
                              "regions",
                              "United Arab Emirates"
                            )
                          }
                        />
                        <FormCheck
                          label="Asia"
                          id="82"
                          onChange={() =>
                            handleCheckboxChange("regions", "Asia")
                          }
                        />
                        <FormCheck
                          label="America"
                          id="83"
                          onChange={() =>
                            handleCheckboxChange("regions", "America")
                          }
                        />
                        <FormCheck
                          label="Oceana"
                          id="84"
                          onChange={() =>
                            handleCheckboxChange("regions", "Oceana")
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">
                          Escrow Account
                        </span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="US"
                          id="85"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "US")
                          }
                        />
                        <FormCheck
                          label="Europe"
                          id="86"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Europe")
                          }
                        />
                        <FormCheck
                          label="Canada"
                          id="87"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Canada")
                          }
                        />
                        <FormCheck
                          label="Africa"
                          id="88"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Africa")
                          }
                        />
                        <FormCheck
                          label="United Arab Emirates"
                          id="89"
                          onChange={() =>
                            handleCheckboxChange(
                              "escrowAccount",
                              "United Arab Emirates"
                            )
                          }
                        />
                        <FormCheck
                          label="Asia"
                          id="90"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Asia")
                          }
                        />
                        <FormCheck
                          label="America"
                          id="91"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "America")
                          }
                        />
                        <FormCheck
                          label="Oceana"
                          id="92"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Oceana")
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">
                          Escrow Account Funds
                        </span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="US"
                          id="93"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "US")
                          }
                        />
                        <FormCheck
                          label="Europe"
                          id="94"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Europe")
                          }
                        />
                        <FormCheck
                          label="Canada"
                          id="95"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Canada")
                          }
                        />
                        <FormCheck
                          label="Africa"
                          id="96"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Africa")
                          }
                        />
                        <FormCheck
                          label="United Arab Emirates"
                          id="97"
                          onChange={() =>
                            handleCheckboxChange(
                              "escrowAccountFunds",
                              "United Arab Emirates"
                            )
                          }
                        />
                        <FormCheck
                          label="Asia"
                          id="98"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Asia")
                          }
                        />
                        <FormCheck
                          label="America"
                          id="99"
                          onChange={() =>
                            handleCheckboxChange(
                              "escrowAccountFunds",
                              "America"
                            )
                          }
                        />
                        <FormCheck
                          label="Oceana"
                          id="100"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Oceana")
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
              </Disclosure.Panel>
            </>
          )}
        </Disclosure>
        <Disclosure as="div" className={`disclosure`}>
          {({ open }) => (
            <>
              <Disclosure.Button
                className={`w-full btn-gradient rounded py-3 px-7 gap-4 justify-between items-center flex ${
                  open && "mb-3"
                }`}
              >
                <span className="whitespace-nowrap sm:text-xl font-medium text-white">
                  Jewelries
                </span>
                <span className="flex-shrink-0">
                  {open ? (
                    <OpenDisclosure className="text-white" />
                  ) : (
                    <CloseDisclosure className="text-white" />
                  )}
                </span>
              </Disclosure.Button>
              <Disclosure.Panel as="div" className="px-8 py-4">
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">
                          Jewelries Types
                        </span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="Necklace"
                          id="101"
                          onChange={() =>
                            handleCheckboxChange("jewelryTypes", "Necklace")
                          }
                        />
                        <FormCheck
                          label="Rings"
                          id="102"
                          onChange={() =>
                            handleCheckboxChange("jewelryTypes", "Rings")
                          }
                        />
                        <FormCheck
                          label="Earrings"
                          id="103"
                          onChange={() =>
                            handleCheckboxChange("jewelryTypes", "Earrings")
                          }
                        />
                        <FormCheck
                          label="Bracelet"
                          id="104"
                          onChange={() =>
                            handleCheckboxChange("jewelryTypes", "Bracelet")
                          }
                        />
                        <FormCheck
                          label="Diamond"
                          id="105"
                          onChange={() =>
                            handleCheckboxChange("jewelryTypes", "Diamond")
                          }
                        />
                        <FormCheck
                          label="Gold"
                          id="106"
                          onChange={() =>
                            handleCheckboxChange("jewelryTypes", "Gold")
                          }
                        />
                        <FormCheck
                          label="Locket"
                          id="107"
                          onChange={() =>
                            handleCheckboxChange("jewelryTypes", "Locket")
                          }
                        />
                        <FormCheck
                          label="Box Chain"
                          id="108"
                          onChange={() =>
                            handleCheckboxChange("jewelryTypes", "Box Chain")
                          }
                        />
                        <FormCheck
                          label="Princes Necklace"
                          id="109"
                          onChange={() =>
                            handleCheckboxChange(
                              "jewelryTypes",
                              "Princes Necklace"
                            )
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">Region</span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="US"
                          id="110"
                          onChange={() => handleCheckboxChange("regions", "US")}
                        />
                        <FormCheck
                          label="Europe"
                          id="111"
                          onChange={() =>
                            handleCheckboxChange("regions", "Europe")
                          }
                        />
                        <FormCheck
                          label="Canada"
                          id="112"
                          onChange={() =>
                            handleCheckboxChange("regions", "Canada")
                          }
                        />
                        <FormCheck
                          label="Africa"
                          id="113"
                          onChange={() =>
                            handleCheckboxChange("regions", "Africa")
                          }
                        />
                        <FormCheck
                          label="United Arab Emirates"
                          id="114"
                          onChange={() =>
                            handleCheckboxChange(
                              "regions",
                              "United Arab Emirates"
                            )
                          }
                        />
                        <FormCheck
                          label="Asia"
                          id="115"
                          onChange={() =>
                            handleCheckboxChange("regions", "Asia")
                          }
                        />
                        <FormCheck
                          label="America"
                          id="116"
                          onChange={() =>
                            handleCheckboxChange("regions", "America")
                          }
                        />
                        <FormCheck
                          label="Oceana"
                          id="117"
                          onChange={() =>
                            handleCheckboxChange("regions", "Oceana")
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">
                          Escrow Account
                        </span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="US"
                          id="118"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "US")
                          }
                        />
                        <FormCheck
                          label="Europe"
                          id="119"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Europe")
                          }
                        />
                        <FormCheck
                          label="Canada"
                          id="120"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Canada")
                          }
                        />
                        <FormCheck
                          label="Africa"
                          id="121"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Africa")
                          }
                        />
                        <FormCheck
                          label="United Arab Emirates"
                          id="122"
                          onChange={() =>
                            handleCheckboxChange(
                              "escrowAccount",
                              "United Arab Emirates"
                            )
                          }
                        />
                        <FormCheck
                          label="Asia"
                          id="123"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Asia")
                          }
                        />
                        <FormCheck
                          label="America"
                          id="124"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "America")
                          }
                        />
                        <FormCheck
                          label="Oceana"
                          id="125"
                          onChange={() =>
                            handleCheckboxChange("escrowAccount", "Oceana")
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
                <Disclosure as="div" className={`mb-4`} defaultOpen={true}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full custom-shadow rounded py-3 px-7 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="whitespace-nowrap">
                          Escrow Account Funds
                        </span>
                        <span className="flex-shrink-0">
                          {open ? <OpenDisclosure /> : <CloseDisclosure />}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel
                        as="div"
                        className="grid sm:grid-cols-2 gap-4 px-8 py-4"
                      >
                        <FormCheck
                          label="US"
                          id="126"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "US")
                          }
                        />
                        <FormCheck
                          label="Europe"
                          id="127"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Europe")
                          }
                        />
                        <FormCheck
                          label="Canada"
                          id="128"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Canada")
                          }
                        />
                        <FormCheck
                          label="Africa"
                          id="129"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Africa")
                          }
                        />
                        <FormCheck
                          label="United Arab Emirates"
                          id="130"
                          onChange={() =>
                            handleCheckboxChange(
                              "escrowAccountFunds",
                              "United Arab Emirates"
                            )
                          }
                        />
                        <FormCheck
                          label="Asia"
                          id="131"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Asia")
                          }
                        />
                        <FormCheck
                          label="America"
                          id="132"
                          onChange={() =>
                            handleCheckboxChange(
                              "escrowAccountFunds",
                              "America"
                            )
                          }
                        />
                        <FormCheck
                          label="Oceana"
                          id="133"
                          onChange={() =>
                            handleCheckboxChange("escrowAccountFunds", "Oceana")
                          }
                        />
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
              </Disclosure.Panel>
            </>
          )}
        </Disclosure>
        <div className="flex justify-end gap-3 me-10 my-3">
          <button
            className="flex justify-center border border-reefGold py-2 px-8 focus:outline-none text-lg font-medium rounded"
            onClick={() => {
              Swal.fire({
                icon: "info",
                title: "Cancelled",
                text: "Your changes have been cancelled!",
              });
            }}
          >
            Cancel
          </button>
          <button
            className="flex text-white justify-center btn-gradient border-0 py-2 px-10 focus:outline-none text-lg font-medium rounded"
            onClick={handleSave}
          >
            Save
          </button>
        </div>
      </div>
    </>
  );
};
